@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2024 the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,14 +22,16 @@
 
 #include <glib.h>
 
-typedef gboolean (*SylpheedHookFunction)	(gpointer source,
+#define HOOK_NONE 0
+
+typedef gboolean (*ClawsMailHookFunction)	(gpointer source,
 						 gpointer userdata);
 
-guint hooks_register_hook	(const gchar		*hooklist_name,
-				 SylpheedHookFunction	 hook_func,
+gulong hooks_register_hook	(const gchar		*hooklist_name,
+				 ClawsMailHookFunction	 hook_func,
 				 gpointer		 userdata);
 void hooks_unregister_hook	(const gchar		*hooklist_name,
-				 guint			 hook_id);
+				 gulong			 hook_id);
 gboolean hooks_invoke		(const gchar		*hooklist_name,
 				 gpointer		 source);
 
