@@ -1,5 +1,5 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
  * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -103,7 +103,7 @@ struct _SMTPSession
 	guchar *send_data;
 	guint send_data_len;
 
-	gint max_message_size;
+	guint max_message_size;
 
 	SMTPAuthType avail_auth_type;
 	SMTPAuthType forced_auth_type;
