@@ -55,6 +55,7 @@ static char *TRANS_TEAM_LIST[] = {
 "[ro] Cristian Secară <liste@secarica.ro>",
 "[ru] Mikhail Kurinnoi <viewizard@viewizard.com>",
 "[sk] Slavko <slavino@slavino.sk>",
+"[sq] Besnik Bleta <besnik@programeshqip.org>",
 "[sv] Andreas Rönnquist <gusnan@openmailbox.org>",
 "[tr] Numan Demirdöğen <if.gnu.linux@gmail.com>",
 "[zh_TW] Mark Chang <mark.cyj@gmail.com>",
@@ -264,9 +265,11 @@ static char *CONTRIBS_LIST[] = {
 "Damian Poddebniak",
 "Marcel Pol",
 "Martin Pool",
+"MatN",
 "Quar",
 "Don Quijote",
 "Steve Rader",
+"Quentin Rameau",
 "Steve Randall",
 "Jens Rantil",
 "Ravemax",
@@ -313,6 +316,7 @@ static char *CONTRIBS_LIST[] = {
 "Pascal Terjan",
 "Thorsten Thielen",
 "Edgar Toernig",
+"Konstantin Tokarev",
 "Masahiro Tomita",
 "Tomita",
 "Topia",
@@ -333,6 +337,8 @@ static char *CONTRIBS_LIST[] = {
 "Rafal Weglarz",
 "Florian Weimer",
 "Martin Wicke",
+"Jan Willamowius",
+"Paul Wolneykien",
 "Bob Woodside",
 "YAMAGUCHI",
 "T. Yamamoto",
